/* t_quant.h -- an algorithm for quantization of discrete probability distributions */
/* 09/04/2011, written by Yuriy A. Reznik <yreznik@ieee.org> */

/* This software and documentation is provided "as is", and the author makes 
 * no representations or warranties, expressed or implied, including, but not
 * limited to warranties of merchantability or fitness for any particular
 * purpose, or that the use of this software or documentation will not infringe 
 * any third parties patents, copyrights, trademarks or other rights. The 
 * author will not be liable for any direct, indirect, special or consequential 
 * damages arising out of any use of the software or documentation. */


#ifndef _T_QUANT_H_
#define _T_QUANT_H_ 1

#ifdef __cplusplus
extern "C" {
#endif

/*
 * Initialize quantization module.
 */
extern void t_init ();

/*
 * Compute number of reconstruction points. 
 * Input:
 *   m - number of dimensions
 *   n - precision parameter
 * Returns: 
 *   number of types with m dimensions and denominator n
 */
extern int t_points (int m, int n);

/*
 * Quantize probability distribution.
 * Input:
 *   p[0..m-1] - distribution to quantize
 *   n -  precision parameter
 * Returns:
 *   index of nearest lattice point
 */
extern int t_quant (int m, int n, float *p);

/*
 * Reconstruct quantized probability distribution. 
 * Input:
 *   m - number of dimensions, n - denominator
 *   i - type index 
 * Output:
 *   p[0..m-1] - reconstructed probability distribution
 * Returns:
 *   1 - success; 0 - invalid index
 */
extern int t_reconst (int m, int n, int i, float *p);

#ifdef __cplusplus
}
#endif

#endif //_T_QUANT_H_
